@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: ecLibDb.php 4414 2011-10-21 12:34:28Z fishbone $
+ * @version    SVN: $Id: ecLibDb.php 4506 2011-12-16 14:48:01Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -96,20 +96,6 @@ class ecLibDb extends BaseDb
 		if ($ret) $retValue = $row['cg_value'];
 		return $retValue;
 	}
-	/**
-	 * デフォルト言語を取得
-	 *
-	 * @param string	デフォルト言語
-	 */
-	/*function getDefaultLanguage()
-	{
-		$retValue = '';
-		$queryStr = 'select sc_value from _system_config ';
-		$queryStr .=  'where sc_id = ?';
-		$ret = $this->selectRecord($queryStr, array('default_lang'), $row);
-		if ($ret) $retValue = $row['sc_value'];
-		return $retValue;
-	}*/
 	/**
 	 * 自動生成会員番号の最大数
 	 *
@@ -234,7 +220,9 @@ class ecLibDb extends BaseDb
 		$queryStr .=   'LEFT JOIN shop_cart ON si_head_serial = sh_serial ';
 		
 		// 商品情報の付加
-		if ($productClass == 'photo'){		// フォトギャラリー商品の場合
+		if (empty($productClass)){			// 一般商品
+			$queryStr .=   'LEFT JOIN product ON si_product_id = pt_id AND sh_language_id = pt_language_id AND pt_deleted = false ';
+		} else if ($productClass == 'photo'){		// フォトギャラリー商品の場合
 			$queryStr .=   'LEFT JOIN photo ON si_product_id = ht_id AND sh_language_id = ht_language_id AND ht_deleted = false ';
 			$queryStr .=   'LEFT JOIN product_type ON si_product_class = py_product_class AND si_product_type_id = py_id AND sh_language_id = py_language_id AND py_deleted = false ';
 		}
@@ -244,6 +232,28 @@ class ecLibDb extends BaseDb
 		$queryStr .=   'ORDER BY cu_index,si_serial';
 		$this->selectLoop($queryStr, array($lang, $productClass, $cartId, $lang), $callback);
 	}
+	/**
+	 * カート内容を商品クラスを取得
+	 *
+	 * @param string	$cartId		カートID
+	 * @param string	$lang		言語
+	 * @return 			array		商品クラス
+	 */
+	function getProductClassInCart($cartId, $lang)
+	{
+		$productClass = array();
+		$queryStr  = 'SELECT DISTINCT si_product_class FROM shop_cart_item LEFT JOIN shop_cart ON si_head_serial = sh_serial ';
+		$queryStr .=   'WHERE sh_id = ? ';
+		$queryStr .=     'AND sh_language_id = ? ';
+		$queryStr .=   'ORDER BY si_product_class';
+		$ret = $this->selectRecords($queryStr, array($cartId, $lang), $rows);
+		if ($ret){
+			for ($i = 0; $i < count($rows); $i++){
+				$productClass[] = $rows[$i]['si_product_class'];
+			}
+		}
+		return $productClass;
+	}
 	/**
 	 * カート商品情報を取得
 	 *
@@ -280,7 +290,9 @@ class ecLibDb extends BaseDb
 		$queryStr .=   'LEFT JOIN shop_cart ON si_head_serial = sh_serial ';
 		
 		// 商品情報の付加
-		if ($productClass == 'photo'){		// フォトギャラリー商品の場合
+		if (empty($productClass)){			// 一般商品
+			$queryStr .=   'LEFT JOIN product ON si_product_id = pt_id AND sh_language_id = pt_language_id AND pt_deleted = false ';
+		} else if ($productClass == 'photo'){		// フォトギャラリー商品の場合
 			$queryStr .=   'LEFT JOIN photo ON si_product_id = ht_id AND sh_language_id = ht_language_id AND ht_deleted = false ';
 			$queryStr .=   'LEFT JOIN product_type ON si_product_class = py_product_class AND si_product_type_id = py_id AND sh_language_id = py_language_id AND py_deleted = false ';
 		}
@@ -477,7 +489,7 @@ class ecLibDb extends BaseDb
 	 * カートヘッダ日付を更新
 	 *
 	 * @param int		$serial				カートシリアル番号
-	 * @return bool							取得 = true, 取得なし= false
+	 * @return bool							成功 = true, 失敗 = false
 	 */
 	function updateCartDt($serial)
 	{
@@ -498,5 +510,65 @@ class ecLibDb extends BaseDb
 		$ret = $this->endTransaction();
 		return true;
 	}
+	/**
+	 * 注文書の状態を更新
+	 *
+	 * @param int		$userId		ユーザID
+	 * @param int		$status		カート状態
+	 * @param string	$lang		言語
+	 * @return bool					成功 = true, 失敗 = false
+	 */
+	function updateOrderSheetStatus($userId, $status, $lang = null)
+	{
+		global $gEnvManager;
+		
+		$serial = 0;
+		if (is_null($lang)) $lang = $gEnvManager->getDefaultLanguage();
+		
+		// トランザクション開始
+		$this->startTransaction();
+		
+		$queryStr  = 'SELECT * FROM order_sheet ';
+		$queryStr .=   'WHERE oe_user_id = ? AND oe_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($userId, $lang), $row);
+		if ($ret) $serial = $row['oe_serial'];
+		
+		// カートヘッダの日付を更新
+		$queryStr  = 'UPDATE order_sheet ';
+		$queryStr .=   'SET oe_status = ? ';
+		$queryStr .=   'WHERE oe_serial = ? ';
+		$this->execStatement($queryStr, array($status, $serial));
+		
+		// トランザクション確定
+		$ret = $this->endTransaction();
+		return true;
+	}
+	/**
+	 * 注文書の状態を取得
+	 *
+	 * @param int		$userId		ユーザID
+	 * @param string	$lang		言語
+	 * @return int					カート状態
+	 */
+	function getOrderSheetStatus($userId, $lang = null)
+	{
+
+		global $gEnvManager;
+
+		$status = 0;
+		$serial = 0;
+		if (is_null($lang)) $lang = $gEnvManager->getDefaultLanguage();
+		
+		$queryStr  = 'SELECT * FROM order_sheet ';
+		$queryStr .=   'WHERE oe_user_id = ? AND oe_language_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($userId, $lang), $row);
+		if ($ret) $serial = $row['oe_serial'];
+		
+		$queryStr  = 'SELECT oe_status FROM order_sheet ';
+		$queryStr .=   'WHERE oe_serial = ?';
+		$ret = $this->selectRecord($queryStr, array($serial), $row);
+		if ($ret) $status = $row['oe_status'];
+		return $status;
+	}
 }
 ?>
