@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: baseWidgetContainer.php 4348 2011-09-24 12:03:23Z fishbone $
+ * @version    SVN: $Id: baseWidgetContainer.php 4557 2012-01-03 12:37:39Z fishbone $
  * @link       http://www.magic3.org
  */
 // テンプレートライブラリ読み込み
@@ -285,6 +285,13 @@ class BaseWidgetContainer extends Core
 				// ヘッダにJavascriptを追加
 				if (!empty($scriptFile)) $this->gPage->addHeadScriptFile($scriptFile);
 			}
+			// 各ウィジェットごとの追加Javascript(jQueryMobile用挿入ファイル)を取得し、ヘッダに設定
+			if (method_exists($this, '_addPreMobileScriptFileToHead')){
+				$scriptFile = $this->_addPreMobileScriptFileToHead($request, $param);
+				
+				// ヘッダにJavascriptを追加
+				if (!empty($scriptFile)) $this->gPage->addHeadPreMobileScriptFile($scriptFile);
+			}
 			// RSS情報を取得し、ヘッダに設定
 			if (method_exists($this, '_addRssFileToHead')){
 				$rssFileInfo = $this->_addRssFileToHead($request, $param);
@@ -307,6 +314,13 @@ class BaseWidgetContainer extends Core
 				// ヘッダにJavascriptを追加
 				if (!empty($script)) $this->gPage->addHeadScript($script);
 			}
+			// 各ウィジェットごとのJavascriptを取得し、ヘッダに設定
+			if (method_exists($this, '_addPreMobileScriptToHead')){
+				$script = $this->_addPreMobileScriptToHead($request, $param);
+				
+				// ヘッダにJavascriptを追加
+				if (!empty($script)) $this->gPage->addHeadPreMobileScript($script);
+			}
 			// 各ウィジェットごとのHead追加文字列を取得し、ヘッダに設定
 			if (method_exists($this, '_addStringToHead')){
 				$str = $this->_addStringToHead($request, $param);
@@ -1754,7 +1768,7 @@ class BaseWidgetContainer extends Core
 		if (!empty($msgExt)) $msgExt .= ', ';
 		$msgExt .= 'widgetid=' . $this->gEnv->getCurrentWidgetId();
 		
-		$this->gOpeLog-writeErrorLog($method, $msg, $code, $msgExt);
+		$this->gOpeLog->writeFatal($method, $msg, $code, $msgExt);
 	}
 	/**
 	 * ユーザ操作通常エラー出力
@@ -2188,6 +2202,16 @@ class BaseWidgetContainer extends Core
 	{
 		return $this->gPage->createWidgetCmdUrl($widgetId, $this->gEnv->getCurrentWidgetId(), $param);
 	}
+	/**
+	 * 自ウィジェットでコマンドを実行するためのURLを作成
+	 *
+	 * @param string $param		ウィジェットに渡すURLパラメータ
+	 * @return string			作成したURL
+	 */
+	function createCmdUrlToCurrentWidget($param)
+	{
+		return $this->gPage->createDirectWidgetCmdUrl($this->gEnv->getCurrentWidgetId(), $param);
+	}
 	/**
 	 * 管理画面起動時の定義IDを取得
 	 *
