@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: textConvManager.php 3946 2011-01-20 05:08:19Z fishbone $
+ * @version    SVN: $Id: textConvManager.php 4449 2011-11-14 12:09:40Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once(M3_SYSTEM_INCLUDE_PATH . '/common/htmlEdit.php');
@@ -745,5 +745,48 @@ class TextConvManager extends Core
 		
 		return $widgetOutput;
     }
+	/**
+	 * 検索用の入力をDB処理用に加工する
+	 *
+	 * ・絞り込み(AND)検索用のキーワード分割
+	 *
+	 * @param string $src		変換するデータ
+	 * @return array $dest		変換後データ
+	 */
+	function parseSearchKeyword($src)
+	{
+		// 全角スペースを半角スペースに変換
+		$destStr = '';
+		$inQuote = false;
+		for ($i = 0; $i < mb_strlen($src); $i++){
+			$char = mb_substr($src , $i, 1);
+	
+			// 「"」で囲まれた範囲は変換しない
+			if ($inQuote){
+				if ($char == '"') $inQuote = false;
+			} else {
+				if ($char == '"'){
+					$inQuote = true;
+				} else if ($char == '　'){
+					$char = ' ';
+				}
+			}
+			$destStr .= $char;
+		}
+
+		// キーワード分割処理
+		preg_match_all('/".*?("|$)|((?<=[\\s",+])|^)[^\\s",+]+/', $destStr, $matches);		// 半角スペースまたは「+」で分割
+		$keywords = array_map(array($this, '_trim_search_keyword'), $matches[0]);
+		return $keywords;
+	}
+	/**
+	 * 検索キーワード処理コールバック関数
+	 *
+	 * @param string $src		検索キーワード
+	 * @return string			変換後データ
+	 */
+	function _trim_search_keyword($src){
+		return trim($src, "\"'\n\r ");
+	}
 }
 ?>
