@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2008 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_ec.sql 2538 2009-11-10 08:24:57Z fishbone $
+-- * @version    SVN: $Id: create_ec.sql 4524 2011-12-26 08:56:24Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -226,6 +226,27 @@ CREATE TABLE product_image (
     UNIQUE               (im_type,      im_id,              im_language_id,          im_size_id,       im_history_index)
 ) TYPE=innodb;
 
+-- 商品クラスマスター
+DROP TABLE IF EXISTS product_class;
+CREATE TABLE product_class (
+    pu_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    pu_id                VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品クラスID
+    pu_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    pu_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    
+    pu_name              VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 名称
+    pu_description       VARCHAR(200)   DEFAULT ''                    NOT NULL,      -- 説明
+    pu_index             INT            DEFAULT 0                     NOT NULL,      -- 表示順(1～)
+
+    pu_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    pu_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    pu_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    pu_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    pu_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (pu_serial),
+    UNIQUE               (pu_id,        pu_language_id,               pu_history_index)
+) TYPE=innodb;
+
 -- 商品カテゴリマスター
 DROP TABLE IF EXISTS product_category;
 CREATE TABLE product_category (
@@ -430,6 +451,28 @@ CREATE TABLE person_info (
     UNIQUE               (pi_id,        pi_language_id,               pi_history_index)
 ) TYPE=innodb;
 
+-- 個人情報追加フィールド
+DROP TABLE IF EXISTS person_info_opt_field;
+CREATE TABLE person_info_opt_field (
+    pf_id                VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- フィールドID
+    pf_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    pf_name              VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 名称
+    pf_field_type        VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- フィールドタイプ
+    pf_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
+    PRIMARY KEY          (pf_id,        pf_language_id)
+) TYPE=innodb;
+
+-- 個人情報追加フィールド値
+DROP TABLE IF EXISTS person_info_opt_value;
+CREATE TABLE person_info_opt_value (
+    pl_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    pl_person_serial     INT            DEFAULT 0                     NOT NULL,      -- 個人情報シリアル番号
+    pl_field_id          VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 個人情報追加フィールドID
+    pl_value             TEXT                                         NOT NULL,      -- 値
+    PRIMARY KEY          (pl_serial),
+    UNIQUE               (pl_person_serial, pl_field_id)
+) TYPE=innodb;
+
 -- 法人情報マスター
 DROP TABLE IF EXISTS company_info;
 CREATE TABLE company_info (
@@ -513,7 +556,9 @@ CREATE TABLE customer (
 DROP TABLE IF EXISTS product_price;
 CREATE TABLE product_price (
     pp_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    pp_product_class     VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品クラス
     pp_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
+    pp_product_type_id   VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプ
     pp_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
     pp_price_type_id     VARCHAR(20)    DEFAULT ''                    NOT NULL,      -- 価格の種別ID(price_typeテーブル)
     pp_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
@@ -529,7 +574,7 @@ CREATE TABLE product_price (
     pp_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
     pp_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
     PRIMARY KEY          (pp_serial),
-    UNIQUE               (pp_product_id,        pp_language_id,      pp_price_type_id,      pp_history_index)
+    UNIQUE               (pp_product_class,     pp_product_id,    pp_product_type_id,    pp_language_id,      pp_price_type_id,      pp_history_index)
 ) TYPE=innodb;
 
 -- 商品情報マスター
@@ -546,7 +591,7 @@ CREATE TABLE product (
     pt_description       TEXT                                         NOT NULL,      -- 商品説明
     pt_description_short VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 商品説明(簡易)
     pt_admin_note        VARCHAR(100)   DEFAULT ''                    NOT NULL,      -- 管理者用備考
-    pt_category_id       INT            DEFAULT 0                     NOT NULL,      -- 商品カテゴリーID
+    pt_category_id       INT            DEFAULT 0                     NOT NULL,      -- 商品カテゴリーID(廃止)
     pt_related_product   TEXT                                         NOT NULL,      -- 関連商品ID(,区切り)
     pt_manufacturer_id   INT            DEFAULT 0                     NOT NULL,      -- メーカーID
     pt_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
@@ -583,6 +628,30 @@ CREATE TABLE product (
     UNIQUE               (pt_id,        pt_language_id,               pt_history_index)
 ) TYPE=innodb;
 
+-- 商品タイプマスター
+DROP TABLE IF EXISTS product_type;
+CREATE TABLE product_type (
+    py_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    py_product_class     VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品クラス
+    py_id                VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプID
+    py_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    py_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+    
+    py_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 名称
+    py_code              VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプコード
+    py_description       VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- 説明
+    py_index             INT            DEFAULT 0                     NOT NULL,      -- 項目順(1～)
+    py_single_select     BOOLEAN        DEFAULT false                 NOT NULL,      -- 単数選択のみ
+
+    py_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    py_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    py_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    py_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    py_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (py_serial),
+    UNIQUE               (py_product_class,     py_id,        py_language_id,               py_history_index)
+) TYPE=innodb;
+
 -- 商品ステータス種別マスター
 DROP TABLE IF EXISTS product_status_type;
 CREATE TABLE product_status_type (
@@ -616,14 +685,16 @@ DROP TABLE IF EXISTS shop_cart_item;
 CREATE TABLE shop_cart_item (
     si_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
     si_head_serial       INT            DEFAULT 0                     NOT NULL,      -- ショッピングカートトランシリアル番号
+    si_product_class     VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品クラス
     si_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
+    si_product_type_id   VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプ
     si_currency_id       VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 通貨種別
     si_quantity          INT            DEFAULT 0                     NOT NULL,      -- 数量
     si_subtotal          DECIMAL(15,4)  DEFAULT 0                     NOT NULL,      -- 税込み小計
     si_active            BOOLEAN        DEFAULT true                  NOT NULL,      -- 購入対象かどうか
     si_available         BOOLEAN        DEFAULT true                  NOT NULL,      -- データ有効性
     PRIMARY KEY          (si_serial),
-    UNIQUE               (si_head_serial,    si_product_id)
+    UNIQUE               (si_head_serial, si_product_class,     si_product_id,    si_product_type_id)
 ) TYPE=innodb;
 
 -- 商品ステータスマスター
@@ -725,6 +796,9 @@ CREATE TABLE order_sheet (
     oe_demand_dt         DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 希望納期(日付)
     oe_demand_time       TEXT                                         NOT NULL,      -- 希望納期(時間帯)
     oe_appoint_dt        DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 予定納期
+    oe_discount_desc     TEXT                                         NOT NULL,      -- 値引き説明
+    oe_status            INT            DEFAULT 0                     NOT NULL,      -- 注文書状態(0=通常、1=オンライン処理中)
+    oe_session           CHAR(32)       DEFAULT ''                    NOT NULL,      -- セッションID
     
     oe_currency_id       VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 通貨ID
     oe_subtotal          DECIMAL(15,4)  DEFAULT 0                     NOT NULL,      -- 商品総額
@@ -805,6 +879,7 @@ CREATE TABLE order_header (
     or_demand_dt         DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 希望納期(日付)
     or_demand_time       TEXT                                         NOT NULL,      -- 希望納期(時間帯)
     or_appoint_dt        DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 予定納期
+    or_discount_desc     TEXT                                         NOT NULL,      -- 値引き説明
     
     or_currency_id       VARCHAR(3)     DEFAULT ''                    NOT NULL,      -- 通貨ID
     or_subtotal          DECIMAL(15,4)  DEFAULT 0                     NOT NULL,      -- 商品総額
@@ -817,6 +892,7 @@ CREATE TABLE order_header (
     or_estimate_dt       TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 見積日時
     or_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 受注受付日時
     or_order_dt          TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 受注処理開始日時
+    or_pay_dt            TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 支払い日時
     or_deliv_dt          TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 配送日時
     or_close_dt          TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 取引終了日時
 
@@ -864,8 +940,11 @@ CREATE TABLE order_detail (
     od_index             INT            DEFAULT 0                     NOT NULL,      -- 明細番号(0～)
     od_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
 
+    od_product_class     VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品クラス
     od_product_id        INT            DEFAULT 0                     NOT NULL,      -- 商品ID
-    od_product_name      VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 商品名
+    od_product_type_id   VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 商品タイプ
+    od_product_name      TEXT                                         NOT NULL,      -- 商品名
+    od_product_code      TEXT                                         NOT NULL,      -- 商品コード
     od_attribute         TEXT                                         NOT NULL,      -- 商品属性(属性メニューの選択値)
     od_note              TEXT                                         NOT NULL,      -- 補足情報
 
