@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2010 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: create_std.sql 4173 2011-06-08 09:14:43Z fishbone $
+-- * @version    SVN: $Id: create_std.sql 4524 2011-12-26 08:56:24Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -1013,3 +1013,112 @@ CREATE TABLE event_entry_with_category (
     UNIQUE               (ew_entry_id,  ew_category_id, ew_category_item_id)
 ) TYPE=innodb;
 
+-- --------------------------------------------------------------------------------------------------
+-- フォトギャラリー用
+-- --------------------------------------------------------------------------------------------------
+-- フォトギャラリー設定マスター
+DROP TABLE IF EXISTS photo_config;
+CREATE TABLE photo_config (
+    hg_id                VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- ID(key)
+    hg_value             TEXT                                         NOT NULL,      -- 値
+    hg_name              VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- 名称
+    hg_description       VARCHAR(160)   DEFAULT ''                    NOT NULL,      -- 説明
+    hg_index             INT            DEFAULT 0                     NOT NULL,      -- ソート用
+    PRIMARY KEY          (hg_id)
+) TYPE=innodb;
+
+-- 写真情報マスター
+DROP TABLE IF EXISTS photo;
+CREATE TABLE photo (
+    ht_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    ht_id                INT            DEFAULT 0                     NOT NULL,      -- 画像ID
+    ht_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    ht_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+
+    ht_public_id         CHAR(32)       DEFAULT ''                    NOT NULL,      -- 公開用画像ID
+    ht_dir               TEXT                                         NOT NULL,      -- 画像格納ディレクトリ
+    ht_code              VARCHAR(50)    DEFAULT ''                    NOT NULL,      -- 画像コード
+    ht_mime_type         VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- 画像MIMEタイプ
+    ht_image_size        VARCHAR(10)    DEFAULT ''                    NOT NULL,      -- 画像縦横サイズ
+    ht_original_filename VARCHAR(256)   DEFAULT ''                    NOT NULL,      -- 元の画像ファイル名
+    ht_file_size         INT            DEFAULT 0                     NOT NULL,      -- ファイルサイズ(バイト)
+    ht_name              VARCHAR(160)   DEFAULT ''                    NOT NULL,      -- 画像名称
+    ht_camera            VARCHAR(80)    DEFAULT ''                    NOT NULL,      -- カメラ
+    ht_location          TEXT                                         NOT NULL,      -- 撮影場所
+    ht_date              DATE           DEFAULT '0000-00-00'          NOT NULL,      -- 撮影日
+    ht_time              INT            DEFAULT 0                     NOT NULL,      -- 撮影時間(hhmm)
+    ht_note              TEXT                                         NOT NULL,      -- 補足情報
+    ht_keyword           TEXT                                         NOT NULL,      -- 検索用キーワード(「,」区切りで複数指定可)
+    ht_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
+    ht_user_limited      BOOLEAN        DEFAULT false                 NOT NULL,      -- 参照ユーザを制限
+    ht_license           VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- ライセンス(ロイヤリティフリー(RF),ライツマネージド(RM))
+    ht_owner_id          INT            DEFAULT 0                     NOT NULL,      -- 所有者ID
+    ht_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- アップロード日時
+    ht_active_start_dt   TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 公開期間(開始)
+    ht_active_end_dt     TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 公開期間(終了)
+    ht_rate_average       DECIMAL(4,2)  DEFAULT 0                     NOT NULL,      -- 評価平均値
+    ht_view_count         INT           DEFAULT 0                     NOT NULL,      -- 参照数
+    
+    ht_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    ht_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    ht_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    ht_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    ht_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (ht_serial),
+    UNIQUE               (ht_id,        ht_language_id,               ht_history_index)
+) TYPE=innodb;
+
+-- 写真カテゴリマスター
+DROP TABLE IF EXISTS photo_category;
+CREATE TABLE photo_category (
+    hc_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    hc_id                INT            DEFAULT 0                     NOT NULL,      -- カテゴリID
+    hc_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    hc_history_index     INT            DEFAULT 0                     NOT NULL,      -- 履歴管理用インデックスNo(0～)
+
+    hc_name              VARCHAR(30)    DEFAULT ''                    NOT NULL,      -- カテゴリ名称
+    hc_parent_id         INT            DEFAULT 0                     NOT NULL,      -- 親カテゴリID
+    hc_password          CHAR(32)       DEFAULT ''                    NOT NULL,      -- アクセス制限パスワード(MD5)
+    hc_sort_order        INT            DEFAULT 0                     NOT NULL,      -- ソート用
+    hc_visible           BOOLEAN        DEFAULT true                  NOT NULL,      -- 表示するかどうか
+
+    hc_create_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード作成者
+    hc_create_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード作成日時
+    hc_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    hc_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    hc_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (hc_serial),
+    UNIQUE               (hc_id,        hc_language_id,  hc_history_index)
+) TYPE=innodb;
+
+-- 写真と写真カテゴリーの対応付けマスター
+DROP TABLE IF EXISTS photo_with_category;
+CREATE TABLE photo_with_category (
+    hw_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    hw_photo_serial      INT            DEFAULT 0                     NOT NULL,      -- 写真情報シリアル番号
+    hw_index             INT            DEFAULT 0                     NOT NULL,      -- インデックス番号(0～)
+    hw_category_id       INT            DEFAULT 0                     NOT NULL,      -- カテゴリID
+    PRIMARY KEY          (hw_serial),
+    UNIQUE               (hw_photo_serial,  hw_index)
+) TYPE=innodb;
+
+-- 画像評価トラン
+DROP TABLE IF EXISTS photo_rate;
+CREATE TABLE photo_rate (
+    hr_serial            INT            AUTO_INCREMENT,                              -- レコードシリアル番号
+    hr_photo_id          INT            DEFAULT 0                     NOT NULL,      -- 画像ID
+    hr_language_id       VARCHAR(2)     DEFAULT ''                    NOT NULL,      -- 言語ID
+    hr_ip                VARCHAR(40)    DEFAULT ''                    NOT NULL,      -- アクセス元IP(IPv6対応)
+    hr_parent_serial     INT            DEFAULT 0                     NOT NULL,      -- 親コメントのシリアル番号
+    hr_user_id           INT            DEFAULT 0                     NOT NULL,      -- ユーザID
+    hr_regist_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- 投稿日時
+    
+    hr_rate_value        SMALLINT       DEFAULT 0                     NOT NULL,      -- 評価値
+    hr_message           TEXT                                         NOT NULL,      -- メッセージ
+    hr_status            SMALLINT       DEFAULT 0                     NOT NULL,      -- 状態(0=未設定、1=非公開、2=公開)
+    
+    hr_update_user_id    INT            DEFAULT 0                     NOT NULL,      -- レコード更新者
+    hr_update_dt         TIMESTAMP      DEFAULT '0000-00-00 00:00:00' NOT NULL,      -- レコード更新日時
+    hr_deleted           BOOLEAN        DEFAULT false                 NOT NULL,      -- レコード削除状態
+    PRIMARY KEY          (hr_serial)
+) TYPE=innodb;
