@@ -9,7 +9,7 @@
 -- * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
 -- * @copyright  Copyright 2006-2011 Magic3 Project.
 -- * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
--- * @version    SVN: $Id: insert_std.sql 4432 2011-11-08 06:03:12Z fishbone $
+-- * @version    SVN: $Id: insert_std.sql 4524 2011-12-26 08:56:24Z fishbone $
 -- * @link       http://www.magic3.org
 -- *
 -- --------------------------------------------------------------------------------------------------
@@ -316,6 +316,25 @@ INSERT INTO event_config
 ('m:entry_view_order',      '1',         '記事表示順(携帯)',                   8),
 ('m:top_contents',          '',          'トップ画面コンテンツ(携帯)',         9);
 
+-- --------------------------------------------------------------------------------------------------
+-- フォトギャラリー用
+-- --------------------------------------------------------------------------------------------------
+-- フォトギャラリー設定マスター
+INSERT INTO photo_config
+(hg_id,                     hg_value,           hg_name,                                  hg_index) VALUES
+('image_protect_copyright',       '1',                '画像著作権保護',                             1),
+('upload_image_max_size',   '500K',             'アップロード画像の最大サイズ(バイト数)', 2),
+('watermark_filename',      'default_mark.jpg', 'セキュリティ保護画像ファイル名',         3),
+('default_image_size',      '160',              '公開画像デフォルトサイズ',               4),
+('default_thumbnail_size',  '128',              'サムネール画像デフォルトサイズ',         5),
+('thumbnail_bg_color',      '#FFFFFF',              'サムネール画像背景色',         6),
+('thumbnail_type',          '0',              'サムネールタイプ',         7),
+('image_category_count',  '2',                '画像カテゴリー数',         8),
+('photo_list_item_count',  '24',                '画像一覧表示項目数',         9),
+('photo_list_order',        '1',         '画像一覧表示順',                         10),
+('photo_title_short_length',  '10',                '画像タイトル(略式)文字数',         11),
+('photo_category_password', '0',                '画像カテゴリーのパスワード制限',             12);
+
 -- --------------------------------------------------------------------------------------------------
 -- 携帯クイズ王ウィジェット用
 -- --------------------------------------------------------------------------------------------------
