@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4455 2011-11-15 08:23:01Z fishbone $
+ * @version    SVN: $Id: photo_mainTopWidgetContainer.php 4522 2011-12-26 00:48:43Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getCurrentWidgetContainerPath() .	'/photo_mainBaseWidgetContainer.php');
@@ -22,6 +22,7 @@ require_once($gEnvManager->getCommonPath() . '/valueCheck.php');
 class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 {
 	private $db;			// DB接続オブジェクト
+	private $categoryDb;	// DB接続オブジェクト
 	private $serialArray = array();		// 表示されている項目シリアル番号
 	private $photoArray;	// 取得した写真
 	private $notfoundThumbnailUrl;		// サムネール画像が見つからない場合の画像
@@ -39,6 +40,8 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	private $sortKey;		// ソートキー
 	private $sortDirection;		// ソート方向
 	private $menuAuthorRows;	// メニュー用の著作者情報
+	private $authCategory;		// 参照可能なカテゴリー
+	private $authCategoryStr;	// 参照可能なカテゴリー(表示用)
 	const CSS_FILE = '/style.css';		// CSSファイルのパス
 	const NOT_FOUND_ICON_FILE = 		'/images/system/notfound128.gif';		// 写真が見つからないアイコン
 	const BACK_ICON_FILE = '/images/system/back.png';		// 「戻る」アイコン
@@ -130,6 +133,8 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$this->rate($request);
 		} else if ($act == 'inputcart'){			// カートに入れる
 			$this->inputCart($request);
+		} else if ($act == 'downloadimage'){			// 画像ダウンロード
+			$this->downloadImage($request);
 		} else {		// 詳細、一覧画面
 			if (empty($this->photoId)){		
 				$this->showList($request);
@@ -138,6 +143,25 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			}
 		}
 	}
+	/**
+	 * JavascriptライブラリをHTMLヘッダ部に設定
+	 *
+	 * JavascriptライブラリをHTMLのheadタグ内に追加出力する。
+	 * _assign()よりも後に実行される。
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param object         $param			任意使用パラメータ。
+	 * @return string,array 				Javascriptライブラリ。出力しない場合は空文字列を設定。
+	 */
+	function _addScriptLibToHead($request, &$param)
+	{
+		// 画像カテゴリーのパスワード制御を行う場合は暗号化ライブラリを追加
+		if (empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD])){
+			return '';
+		} else {
+			return 'md5';
+		}
+	}
 	/**
 	 * CSSファイルをHTMLヘッダ部に設定
 	 *
@@ -161,7 +185,7 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	function showList($request)
 	{
 		// DBオブジェクト
-		$categoryDb = new photo_categoryDb();
+		$this->categoryDb = new photo_categoryDb();
 		
 		// 初期設定
 		$paramObj = $this->getWidgetParamObj();
@@ -193,7 +217,62 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$category = $request->trimValueOf('category');		// カテゴリー
 		$author = $request->trimValueOf('author');			// 著作者
 		$sort = $request->trimValueOf('sort');		// ソート順
+		$act = $request->trimValueOf('act');
+		
+		// 画像カテゴリーにパスワード制限を掛けている場合の処理
+		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD])){
+			$this->authCategory = array();		// 参照可能なカテゴリー
+				
+			// ブラウザのクライアントIDを取得
+			$cid = $this->gAccess->getClientId();
+			if (!empty($cid)){
+				// クライアントパラメータオブジェクトを取得
+				$clientObj = $this->getClientParamObj($cid, $this->gEnv->getCurrentWidgetId());
+				if (!empty($clientObj) && !empty($clientObj->authCategory)){
+					$this->authCategory = explode(',', $clientObj->authCategory);
+				}
+			
+				if ($act == 'addcategory'){			// 参照カテゴリー追加のとき
+					$accessCategoryId = $request->trimValueOf('access_category');			// 参照するカテゴリー
+					$password = $request->trimValueOf('password');
+				
+					// 画像カテゴリーのパスワードをチェック
+					$ret = $this->categoryDb->getCategoryByCategoryId($accessCategoryId, $this->_langId, $row);
+					if ($ret && $row['hc_password'] == $password){
+						// 画像カテゴリーを追加
+						if (!in_array($accessCategoryId, $this->authCategory)) $this->authCategory[] = $accessCategoryId;
+					
+						// クライアントパラメータを更新
+						$clientObj->authCategory = implode(',', $this->authCategory);
+						$ret = $this->updateClientParamObj($cid, $this->gEnv->getCurrentWidgetId(), $clientObj);
+						$this->setGuidanceMsg('追加しました');
+					} else {
+						// 認証に失敗した画像カテゴリーは削除する
+						$destAuthCategory = array();
+						for ($i = 0; $i < count($this->authCategory); $i++){
+							if ($this->authCategory[$i] != $accessCategoryId) $destAuthCategory[] = $this->authCategory[$i];
+						}
+						$this->authCategory = $destAuthCategory;
+					
+						// クライアントパラメータを更新
+						$clientObj->authCategory = implode(',', $this->authCategory);
+						$ret = $this->updateClientParamObj($cid, $this->gEnv->getCurrentWidgetId(), $clientObj);
+						$this->setAppErrorMsg('追加に失敗しました');
+					}
+				}
+			}
+			$this->tmpl->setAttribute('category_script', 'visibility', 'visible');		// 画像カテゴリースクリプト表示
+			$this->tmpl->setAttribute('category_area', 'visibility', 'visible');		// 画像カテゴリーエリア表示
 
+			// 画像カテゴリー選択メニュー作成
+			$this->authCategoryStr = '';
+			$this->categoryDb->getAllCategory($this->_langId, array($this, 'categoryListLoop'), true);
+		
+			// 参照可能カテゴリー表示
+			$this->authCategoryStr = rtrim($this->authCategoryStr, ', ');
+			$this->tmpl->addVar("category_area", "auth_category_list", $this->convertToDispString($this->authCategoryStr));
+		}
+		
 		// データエラーチェック
 		$this->checkInputValues($category, $author, $sort);
 		
@@ -209,11 +288,13 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 				$this->gInstance->getAnalyzeManager()->logSearchWord($this->gEnv->getCurrentWidgetId(), $parsedKeywords[$i]);
 			}
 		}
-				
+
 		// 写真数を取得
+		$limitedCategory = $this->authCategory;
+		if (!is_null($limitedCategory) && count($limitedCategory) == 0) $limitedCategory = array('0');		// 空の場合はダミーのカテゴリーIDを追加
 		$totalCount = self::$_mainDb->searchPhotoItemCount($this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/,
-															$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/);
-		
+															$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $limitedCategory);
+
 		// リンク文字列作成、ページ番号調整
 		$this->calcPage($pageNo, $totalCount, $this->viewCount, $pageCount, $startNo, $endNo);
 		
@@ -227,12 +308,12 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$this->tmpl->addVar("page_link_top", "page_link", $pageLink);
 			$this->tmpl->addVar("page_link_bottom", "page_link", $pageLink);
 		}
-		
+
 		// AJAX用URL、詳細画面用URL
 		$ajaxUrl = 'act=getlist&' . M3_REQUEST_PARAM_PAGE_NO . '=' . $pageNo . $urlParams;
 		
 		// 検索カテゴリ情報を取得
-		$ret = $categoryDb->getAllCategoryForMenu($this->_langId, $menuCategoryArray, $rows);
+		$ret = $this->categoryDb->getAllCategoryForMenu($this->_langId, $menuCategoryArray, $rows);
 		if ($ret){
 			$category = array();
 			$parentCategory = '';
@@ -289,6 +370,20 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$author = $request->trimValueOf('author');			// 著作者
 		$sort = $request->trimValueOf('sort');		// ソート順
 
+		// 画像カテゴリーにパスワード制限を掛けている場合の処理
+		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD])){
+			// 参照可能なカテゴリーを取得
+			$this->authCategory = array();
+			$cid = $this->gAccess->getClientId();		// ブラウザのクライアントIDを取得
+			if (!empty($cid)){
+				// クライアントパラメータオブジェクトを取得
+				$clientObj = $this->getClientParamObj($cid, $this->gEnv->getCurrentWidgetId());
+				if (!empty($clientObj) && !empty($clientObj->authCategory)){
+					$this->authCategory = explode(',', $clientObj->authCategory);
+				}
+			}
+		}
+		
 		// データエラーチェック
 		$this->checkInputValues($category, $author, $sort);
 		
@@ -301,8 +396,11 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		// デフォルトでは最新の登録画像を取得
 		$this->photoArray = array();	// 取得した写真
 		$this->startNo = $this->viewCount * ($pageNo -1) + 1;
+		$limitedCategory = $this->authCategory;
+		if (!is_null($limitedCategory) && count($limitedCategory) == 0) $limitedCategory = array('0');		// 空の場合はダミーのカテゴリーIDを追加
 		self::$_mainDb->searchPhotoItem($this->viewCount, $pageNo, $this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/,
-						$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/, array($this, 'viewListLoop'), $urlParams);
+						$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/,
+						array($this, 'viewListLoop'), $urlParams, $limitedCategory);
 
 		// Ajax戻りデータ
 		$this->gInstance->getAjaxManager()->addData('items', $this->photoArray);
@@ -319,8 +417,34 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 	{
 		$commentDb = new photo_commentDb();
 		
+		// 画像カテゴリーにパスワード制限を掛けている場合の処理
+		if (!empty(self::$_configArray[photo_mainCommonDef::CF_PHOTO_CATEGORY_PASSWORD])){
+			// 参照可能なカテゴリーを取得
+			$this->authCategory = array();
+			$cid = $this->gAccess->getClientId();		// ブラウザのクライアントIDを取得
+			if (!empty($cid)){
+				// クライアントパラメータオブジェクトを取得
+				$clientObj = $this->getClientParamObj($cid, $this->gEnv->getCurrentWidgetId());
+				if (!empty($clientObj) && !empty($clientObj->authCategory)){
+					$this->authCategory = explode(',', $clientObj->authCategory);
+				}
+			}
+		}
+		
 		$ret = self::$_mainDb->getSearchPhotoInfo($this->photoId, $this->_langId, $row, $categoryRows);
 		if ($ret){
+			// カテゴリーのアクセスチェック
+			if (!is_null($this->authCategory)){
+				for ($i = 0; $i < count($categoryRows); $i++){
+					if (in_array($categoryRows[$i]['hc_id'], $this->authCategory)) break;
+				}
+				if ($i == count($categoryRows)){
+					$this->setUserErrorMsg('画像が見つかりません');
+					$this->writeUserError(__METHOD__, '不正な画像アクセスを検出しました。画像タイトル=' . $row['ht_name'], 2200, '公開画像ID=' . $this->photoId);
+					return;
+				}
+			}
+			
 			// URLパラメータ
 			$itemNo = $request->trimValueOf(M3_REQUEST_PARAM_ITEM_NO);		// 画像No
 			if (!ValueCheck::isNumeric($itemNo)) $itemNo = 1;
@@ -374,8 +498,11 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			
 			// 前後のリンクを取得
 			$this->startNo = $request->trimIntValueOf(M3_REQUEST_PARAM_ITEM_NO, '1');
+			$limitedCategory = $this->authCategory;
+			if (!is_null($limitedCategory) && count($limitedCategory) == 0) $limitedCategory = array('0');		// 空の場合はダミーのカテゴリーIDを追加
 			self::$_mainDb->searchPhotoItemByNo(3, $this->startNo -1, $this->_langId, null/*開始日時*/, null/*終了日時*/, $parsedKeywords/*キーワード*/, 
-					$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/, array($this, 'prevNextListLoop'), $urlParams);
+					$this->categoryArray/*カテゴリー*/, $this->authorArray/*撮影者*/, $this->sortKey/*ソートキー*/, $this->sortDirection/*ソート方向*/,
+					array($this, 'prevNextListLoop'), $urlParams, $limitedCategory);
 		
 			// 戻り先一覧画面のURLを取得
 			$backUrl = $this->currentPageUrl;
@@ -399,44 +526,62 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 			$commentDb->getCommentByPublicPhotoId(photo_mainCommonDef::DEFAULT_COMMENT_COUNT, 1/**/, $this->photoId, $this->_langId, array($this, 'commentListLoop'));
 			if (count($this->serialArray) == 0) $this->tmpl->setAttribute('itemlist', 'visibility', 'hidden');
 			
+			// 画像情報を表示
+			$this->tmpl->setAttribute('photo_info_script', 'visibility', 'visible');
+			$this->tmpl->setAttribute('photo_info_area', 'visibility', 'visible');
+			
 			// オンラインショップ機能
 			if (!empty(self::$_configArray[photo_mainCommonDef::CF_ONLINE_SHOP])){
 				$this->tmpl->setAttribute('product_script', 'visibility', 'visible');
 				$this->tmpl->setAttribute('product_info', 'visibility', 'visible');
+				
+				// ダウンロード権のチェック
+				$canDownloadImage = false;
+				$ret = self::$_mainDb->getContentAccess($this->_userId, M3_VIEW_TYPE_PHOTO, $row['ht_id'], $accessRow);
+				if ($ret){
+					if ($accessRow['cs_download']) $canDownloadImage = true;
+				}
+				
+				if ($canDownloadImage){
+					$this->tmpl->setAttribute('product_download', 'visibility', 'visible');
+				} else {
+					$this->tmpl->setAttribute('product_cart', 'visibility', 'visible');
+				}
 			}
-			
-			$this->tmpl->addVar("_widget", "photo_id", $this->photoId);
-			$this->tmpl->addVar("_widget", "author", $this->convertToDispString($author));
-			$this->tmpl->addVar("_widget", "place", $this->convertToDispString($row['ht_location']));
-			$this->tmpl->addVar("_widget", "camera", $this->convertToDispString($row['ht_camera']));
-			$this->tmpl->addVar("_widget", "note", $this->convertToDispString($row['ht_note']));
-			$this->tmpl->addVar("_widget", "date", $this->convertToDispDate($date));
-			$this->tmpl->addVar("_widget", "category", $this->convertToDispString($categoryStr));
-			$this->tmpl->addVar("_widget", "img_url", $this->getUrl($imageUrl));
-			$this->tmpl->addVar("_widget", "width", $width);
-			$this->tmpl->addVar("_widget", "height", $height);
-			$this->tmpl->addVar("_widget", "title", $this->convertToDispString($title));
-			$this->tmpl->addVar("_widget", "permalink", $permaLink);
-			$this->tmpl->addVar("_widget", "alt", $this->convertToDispString($alt));
-			$this->tmpl->addVar("_widget", "back_url", $this->convertUrlToHtmlEntity($this->getUrl($backUrl, true/*リンク用*/)));// 「戻る」リンク
-			$this->tmpl->addVar("_widget", "back_img_url", $this->getUrl($this->gEnv->getRootUrl() . self::BACK_ICON_FILE));// 「戻る」アイコン
-			$this->tmpl->addVar("_widget", "icon_size", photo_mainCommonDef::BUTTON_ICON_SIZE);
-			$this->tmpl->addVar("_widget", "back_title", self::BACK_BUTTON_TITLE);
-			$this->tmpl->addVar("_widget", "back_alt", self::BACK_BUTTON_TITLE);
-			$this->tmpl->addVar('_widget', 'raty_image_url', $this->getUrl($this->gEnv->getScriptsUrl() . self::RATY_IMAGE_DIR));	// jquery.raty画像パス
-			$this->tmpl->addVar("_widget", "init_rate", $this->convertToDispString($row['ht_rate_average']));		// 評価値
-			$this->tmpl->addVar("_widget", "rate_disabled", $rateDisabled);			// 「投票する」ボタン使用可否
-			$this->tmpl->addVar("_widget", "comment_count", count($this->serialArray));		// コメント数
+			// 画像情報
+			$this->tmpl->addVar("photo_info_area", "photo_id", $this->photoId);
+			$this->tmpl->addVar("photo_info_area", "author", $this->convertToDispString($author));
+			$this->tmpl->addVar("photo_info_area", "place", $this->convertToDispString($row['ht_location']));
+			$this->tmpl->addVar("photo_info_area", "camera", $this->convertToDispString($row['ht_camera']));
+			$this->tmpl->addVar("photo_info_area", "note", $this->convertToDispString($row['ht_note']));
+			$this->tmpl->addVar("photo_info_area", "date", $this->convertToDispDate($date));
+			$this->tmpl->addVar("photo_info_area", "category", $this->convertToDispString($categoryStr));
+			$this->tmpl->addVar("photo_info_area", "img_url", $this->getUrl($imageUrl));
+			$this->tmpl->addVar("photo_info_area", "width", $width);
+			$this->tmpl->addVar("photo_info_area", "height", $height);
+			$this->tmpl->addVar("photo_info_area", "title", $this->convertToDispString($title));
+			$this->tmpl->addVar("photo_info_area", "permalink", $permaLink);
+			$this->tmpl->addVar("photo_info_area", "alt", $this->convertToDispString($alt));
+			$this->tmpl->addVar("photo_info_area", "back_url", $this->convertUrlToHtmlEntity($this->getUrl($backUrl, true/*リンク用*/)));// 「戻る」リンク
+			$this->tmpl->addVar("photo_info_area", "back_img_url", $this->getUrl($this->gEnv->getRootUrl() . self::BACK_ICON_FILE));// 「戻る」アイコン
+			$this->tmpl->addVar("photo_info_area", "icon_size", photo_mainCommonDef::BUTTON_ICON_SIZE);
+			$this->tmpl->addVar("photo_info_area", "back_title", self::BACK_BUTTON_TITLE);
+			$this->tmpl->addVar("photo_info_area", "back_alt", self::BACK_BUTTON_TITLE);
+			// スクリプト部
+			$this->tmpl->addVar('photo_info_script', 'raty_image_url', $this->getUrl($this->gEnv->getScriptsUrl() . self::RATY_IMAGE_DIR));	// jquery.raty画像パス
+			$this->tmpl->addVar("photo_info_script", "init_rate", $this->convertToDispString($row['ht_rate_average']));		// 評価値
+			$this->tmpl->addVar("photo_info_area", "rate_disabled", $rateDisabled);			// 「投票する」ボタン使用可否
+			$this->tmpl->addVar("photo_info_area", "comment_count", count($this->serialArray));		// コメント数
 			
 			// ハッシュキー作成
 			$postTicket = md5(time() . $this->gAccess->getAccessLogSerialNo());
 			$request->setSessionValue(M3_SESSION_POST_TICKET, $postTicket);		// セッションに保存
-			$this->tmpl->addVar("_widget", "ticket", $postTicket);				// 画面に書き出し
+			$this->tmpl->addVar("photo_info_area", "ticket", $postTicket);				// 画面に書き出し
 				
 			// ビューカウントを更新
 			if (!$this->gEnv->isSystemManageUser()){		// システム運用者以上の場合はカウントしない
 				// 詳細な参照情報
-				$this->gInstance->getAnalyzeManager()->updateContentViewCount(photo_mainCommonDef::REF_CONTENT_TYPE, $row['ht_id'], $this->currentDay, $this->currentHour);
+				$this->gInstance->getAnalyzeManager()->updateContentViewCount(photo_mainCommonDef::REF_TYPE_CONTENT, $row['ht_id'], $this->currentDay, $this->currentHour);
 				
 				// 画像情報の参照数更新
 				self::$_mainDb->updatePhotoInfoViewCount($row['ht_serial']);
@@ -584,6 +729,67 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		$cartPage = $this->createCmdUrlToWidget(self::TARGET_WIDGET, 'task=cart');
 		$this->gPage->redirect($cartPage);
 	}
+	/**
+	 * 画像ダウンロード処理
+	 *
+	 * @param RequestManager $request		HTTPリクエスト処理クラス
+	 * @param								なし
+	 */
+	function downloadImage($request)
+	{
+		$ret = self::$_mainDb->getSearchPhotoInfo($this->photoId, $this->_langId, $row, $categoryRows);
+		if (!$ret){
+			$this->gOpeLog->writeUserAccess(__METHOD__, '不正なダウンロードを検出しました。画像情報が取得できません。', 2200, 'ダウンロードをブロックしました。公開画像ID=' . $this->photoId);
+			return;
+		}
+		
+		// アクセス権をチェック
+		$canDownloadImage = false;
+		$ret = self::$_mainDb->getContentAccess($this->_userId, M3_VIEW_TYPE_PHOTO, $row['ht_id'], $accessRow);
+		if ($ret){
+			if ($accessRow['cs_download']) $canDownloadImage = true;
+		}
+		if (!$canDownloadImage){
+			$this->gOpeLog->writeUserAccess(__METHOD__, '不正なダウンロードを検出しました。ダウンロード権限がありません。', 2200, 'ダウンロードをブロックしました。画像コード=' . $row['ht_code']);
+			return;
+		}
+				
+		// ページ作成処理中断
+		$this->gPage->abortPage();
+		
+		// ダウンロード画像ファイル名作成
+		// 画像フォーマット
+		$mimeType = $row['ht_mime_type'];
+		if ($mimeType == image_type_to_mime_type(IMAGETYPE_GIF)){
+			$ext = '.gif';
+		} else if ($mimeType == image_type_to_mime_type(IMAGETYPE_JPEG)){
+			$ext = '.jpg';
+		} else if ($mimeType == image_type_to_mime_type(IMAGETYPE_PNG)){
+			$ext = '.png';
+		} else if ($mimeType == image_type_to_mime_type(IMAGETYPE_BMP)){
+			$ext = '.bmp';
+		}
+		$downloadFilename = strtr($row['ht_name'], ' ', '_') . $ext;		// 半角スペースを「_」に変換
+
+		// ダウンロード処理
+		$imagePath = $this->gEnv->getIncludePath() . photo_mainCommonDef::PHOTO_DIR . $row['ht_dir'] . DIRECTORY_SEPARATOR . $row['ht_public_id'];
+		if (file_exists($imagePath)){
+			$ret = $this->gPage->downloadFile($imagePath, $downloadFilename);
+			
+			// ダウンロード数更新
+			if (!$this->gEnv->isSystemManageUser()){		// システム運用者以上の場合はカウントしない
+				$this->gInstance->getAnalyzeManager()->updateContentViewCount(photo_mainCommonDef::REF_TYPE_DOWNLOAD, $row['ht_id'], $this->currentDay, $this->currentHour);
+				
+				// ダウンロードを記録
+				$this->gInstance->getAnalyzeManager()->logContentDownload(M3_VIEW_TYPE_PHOTO, $row['ht_id']);
+			}
+		} else {			// 画像がみつからない場合
+			$this->writeError(__METHOD__, '画像が見つからないため、ダウンロードできません。', 1100, '画像コード=' . $row['ht_code'] . ',ファイル名=' . $imagePath);
+		}
+		
+		// システム強制終了
+		$this->gPage->exitSystem();
+	}
 	/**
 	 * 取得したコンテンツ項目をテンプレートに設定する
 	 *
@@ -675,6 +881,35 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		}
 		return true;
 	}
+	/**
+	 * 取得したデータをテンプレートに設定する
+	 *
+	 * @param int $index			行番号(0～)
+	 * @param array $fetchedRow		フェッチ取得した行
+	 * @param object $param			未使用
+	 * @return bool					true=処理続行の場合、false=処理終了の場合
+	 */
+	function categoryListLoop($index, $fetchedRow, $param)
+	{
+		$id = $fetchedRow['hc_id'];// カテゴリ項目ID
+		$name = $fetchedRow['hc_name'];		// カテゴリ項目名
+		$selected = '';
+		
+		// 既にアクセス可能になっているカテゴリーは表示しない
+		if (in_array($id, $this->authCategory)){
+			$this->authCategoryStr .= $name . ',';	// 参照可能なカテゴリー(表示用)
+			return true;
+		}
+		
+		$row = array(
+			'value' => $this->convertToDispString($id),		// カテゴリ項目ID
+			'name' => $this->convertToDispString($name),	// カテゴリ項目名
+			'selected'	=> $selected						// 選択中かどうか
+		);
+		$this->tmpl->addVars('access_category_list', $row);
+		$this->tmpl->parseTemplate('access_category_list', 'a');
+		return true;
+	}
 	/**
 	 * ヘッダ部メタタグの設定
 	 *
@@ -692,20 +927,6 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 							'keywords' => $this->headKeyword);
 		return $headData;
 	}
-	/**
-	 * JavascriptライブラリをHTMLヘッダ部に設定
-	 *
-	 * JavascriptライブラリをHTMLのheadタグ内に追加出力する。
-	 * _assign()よりも後に実行される。
-	 *
-	 * @param RequestManager $request		HTTPリクエスト処理クラス
-	 * @param object         $param			任意使用パラメータ。
-	 * @return string,array 				Javascriptライブラリ。出力しない場合は空文字列を設定。
-	 */
-	function _addScriptLibToHead($request, &$param)
-	{
-		return $this->addLib;
-	}
 	/**
 	 * 検索テンプレートデータ作成処理コールバック
 	 *
@@ -940,5 +1161,39 @@ class photo_mainTopWidgetContainer extends photo_mainBaseWidgetContainer
 		if (!empty($sort)) $params .= '&sort' . '=' . $sort;// ソート順
 		return $params;
 	}
+	/**
+	 * クライアントパラメータオブジェクトを取得
+	 *
+	 * @param string $clientId	クライアントID
+	 * @param string $widgetId	ウィジェットID
+	 * @return object			パラメータオブジェクト。取得できないときはnull。
+	 */
+	function getClientParamObj($clientId, $widgetId)
+	{
+		$serializedParam = self::$_mainDb->getClientParam($clientId, $widgetId);
+		if (empty($serializedParam)){
+			return null;
+		} else {
+			return unserialize($serializedParam);
+		}
+	}
+	/**
+	 * クライアントパラメータオブジェクトを更新
+	 *
+	 * @param string $clientId	クライアントID
+	 * @param string $widgetId	ウィジェットID
+	 * @param object $obj		格納するウィジェットパラメータオブジェクト
+	 * @return bool				true=更新成功、false=更新失敗
+	 */
+	function updateClientParamObj($clientId, $widgetId, $obj)
+	{
+		if (empty($obj)){
+			$updateObj = null;
+		} else {
+			$updateObj = serialize($obj);
+		}
+		$ret = self::$_mainDb->updateClientParam($clientId, $widgetId, $updateObj);
+		return $ret;
+	}
 }
 ?>
