@@ -10,7 +10,7 @@
  * @author     平田直毅(Naoki Hirata) <naoki@aplo.co.jp>
  * @copyright  Copyright 2006-2011 Magic3 Project.
  * @license    http://www.gnu.org/copyleft/gpl.html  GPL License
- * @version    SVN: $Id: photo_mainDb.php 4455 2011-11-15 08:23:01Z fishbone $
+ * @version    SVN: $Id: photo_mainDb.php 4521 2011-12-25 13:43:02Z fishbone $
  * @link       http://www.magic3.org
  */
 require_once($gEnvManager->getDbPath() . '/baseDb.php');
@@ -538,9 +538,10 @@ class photo_mainDb extends BaseDb
 	 * @param int		$sortDirection		取得順(0=降順,1=昇順)
 	 * @param function	$callback			コールバック関数
 	 * @param string    $urlOthers			URL付加パラメータ
+	 * @param array     $authCategory		参照可能なカテゴリー
 	 * @return 			なし
 	 */
-	function searchPhotoItem($limit, $page, $langId, $startDt, $endDt, $keywords, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers)
+	function searchPhotoItem($limit, $page, $langId, $startDt, $endDt, $keywords, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers, $authCategory = null)
 	{
 		$offset = $limit * ($page -1);
 		if ($offset < 0) $offset = 0;
@@ -557,7 +558,7 @@ class photo_mainDb extends BaseDb
 		}*/
 		//$queryStr  = 'SELECT * FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
 		$queryStr  = 'SELECT DISTINCT ht_public_id,ht_name,ht_rate_average,ht_view_count,ht_regist_dt FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
-		if (!empty($category)) $queryStr .=  'RIGHT JOIN photo_with_category ON ht_serial = hw_photo_serial ';
+		if (!empty($category) || !empty($authCategory)) $queryStr .=  'RIGHT JOIN photo_with_category ON ht_serial = hw_photo_serial ';
 		$queryStr .=  'WHERE ht_deleted = false ';		// 未削除
 		$queryStr .=    'AND ht_visible = true ';		// 公開中
 		
@@ -570,6 +571,15 @@ class photo_mainDb extends BaseDb
 			$idStr = rtrim($idStr, ',');
 			$queryStr .=  'AND hw_category_id in (' . $idStr . ') ';
 		}
+		// 参照可能なカテゴリー
+		if (!empty($authCategory)){
+			$queryStr .=  'AND (';
+			for ($i = 0; $i < count($authCategory); $i++){
+				$queryStr .=  'hw_category_id = ' . addslashes($authCategory[$i]) . ' ';
+				if ($i < count($authCategory) -1) $queryStr .=  'OR ';
+			}
+			$queryStr .=  ') ';
+		}
 		// キーワード検索
 		if (!empty($keywords)){
 			for ($i = 0; $i < count($keywords); $i++){
@@ -625,9 +635,10 @@ class photo_mainDb extends BaseDb
 	 * @param int		$sortDirection		取得順(0=降順,1=昇順)
 	 * @param function	$callback			コールバック関数
 	 * @param string    $urlOthers			URL付加パラメータ
+	 * @param array     $authCategory		参照可能なカテゴリー
 	 * @return 			なし
 	 */
-	function searchPhotoItemByNo($limit, $no, $langId, $startDt, $endDt, $keywords, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers)
+	function searchPhotoItemByNo($limit, $no, $langId, $startDt, $endDt, $keywords, $category, $author, $sortKey, $sortDirection, $callback, $urlOthers, $authCategory = null)
 	{
 		$offset = $no -1;
 		if ($offset < 0) $offset = 0;
@@ -644,7 +655,7 @@ class photo_mainDb extends BaseDb
 		}*/
 		//$queryStr  = 'SELECT * FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
 		$queryStr  = 'SELECT DISTINCT ht_public_id,ht_name,ht_rate_average,ht_view_count,ht_regist_dt FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
-		if (!empty($category)) $queryStr .=  'RIGHT JOIN photo_with_category ON ht_serial = hw_photo_serial ';
+		if (!empty($category) || !empty($authCategory)) $queryStr .=  'RIGHT JOIN photo_with_category ON ht_serial = hw_photo_serial ';
 		$queryStr .=  'WHERE ht_deleted = false ';		// 未削除
 		$queryStr .=    'AND ht_visible = true ';		// 公開中
 		
@@ -657,6 +668,15 @@ class photo_mainDb extends BaseDb
 			$idStr = rtrim($idStr, ',');
 			$queryStr .=  'AND hw_category_id in (' . $idStr . ') ';
 		}
+		// 参照可能なカテゴリー
+		if (!empty($authCategory)){
+			$queryStr .=  'AND (';
+			for ($i = 0; $i < count($authCategory); $i++){
+				$queryStr .=  'hw_category_id = ' . addslashes($authCategory[$i]) . ' ';
+				if ($i < count($authCategory) -1) $queryStr .=  'OR ';
+			}
+			$queryStr .=  ') ';
+		}
 		// キーワード検索
 		if (!empty($keywords)){
 			for ($i = 0; $i < count($keywords); $i++){
@@ -706,9 +726,10 @@ class photo_mainDb extends BaseDb
 	 * @param array		$keywords			検索キーワード
 	 * @param array		$category			カテゴリーID
 	 * @param array		$author				撮影者
+	 * @param array     $authCategory		参照可能なカテゴリー
 	 * @return 			なし
 	 */
-	function searchPhotoItemCount($langId, $startDt, $endDt, $keywords, $category, $author)
+	function searchPhotoItemCount($langId, $startDt, $endDt, $keywords, $category, $author, $authCategory = null)
 	{
 		// 日付範囲
 		/*
@@ -722,7 +743,7 @@ class photo_mainDb extends BaseDb
 		}*/
 		//$queryStr  = 'SELECT * FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
 		$queryStr  = 'SELECT DISTINCT ht_public_id,ht_name,ht_rate_average,ht_view_count,ht_regist_dt FROM photo LEFT JOIN _login_user ON ht_owner_id = lu_id AND lu_deleted = false ';
-		if (!empty($category)) $queryStr .=  'RIGHT JOIN photo_with_category ON ht_serial = hw_photo_serial ';
+		if (!empty($category) || !empty($authCategory)) $queryStr .=  'RIGHT JOIN photo_with_category ON ht_serial = hw_photo_serial ';
 		$queryStr .=  'WHERE ht_deleted = false ';		// 未削除
 		$queryStr .=    'AND ht_visible = true ';		// 公開中
 		
@@ -735,6 +756,15 @@ class photo_mainDb extends BaseDb
 			$idStr = rtrim($idStr, ',');
 			$queryStr .=  'AND hw_category_id in (' . $idStr . ') ';
 		}
+		// 参照可能なカテゴリー
+		if (!empty($authCategory)){
+			$queryStr .=  'AND (';
+			for ($i = 0; $i < count($authCategory); $i++){
+				$queryStr .=  'hw_category_id = ' . addslashes($authCategory[$i]) . ' ';
+				if ($i < count($authCategory) -1) $queryStr .=  'OR ';
+			}
+			$queryStr .=  ') ';
+		}
 		// キーワード検索
 		if (!empty($keywords)){
 			for ($i = 0; $i < count($keywords); $i++){
@@ -841,5 +871,74 @@ class photo_mainDb extends BaseDb
 		$ret = $this->selectRecord($queryStr, array(''/*デフォルトコンテンツ*/, $key, $langId), $row);
 		return $ret;
 	}
+	/**
+	 * コンテンツのアクセス権を取得
+	 *
+	 * @param int	 $userId		ユーザID
+	 * @param strin  $contentType	コンテンツタイプ
+	 * @param int	 $contentId		コンテンツID
+	 * @param array     $row				レコード
+	 * @return bool							取得 = true, 取得なし= false
+	 */
+	function getContentAccess($userId, $contentType, $contentId, &$row)
+	{
+		$queryStr  = 'SELECT * FROM _content_access ';
+		$queryStr .=   'WHERE cs_user_id = ? ';
+		$queryStr .=   'AND cs_content_type = ? ';
+		$queryStr .=   'AND cs_content_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($userId, $contentType, $contentId), $row);
+		return $ret;
+	}
+	/**
+	 * クライアント設定値を取得
+	 *
+	 * @param string $clientId		クライアントID
+	 * @param string $widgetId		ウィジェットID
+	 * @return string				値
+	 */
+	function getClientParam($clientId, $widgetId)
+	{
+		$retValue = '';
+		$queryStr  = 'SELECT * FROM _client_param ';
+		$queryStr .=   'WHERE cp_id  = ? ';
+		$queryStr .=     'AND cp_widget_id = ? ';
+		$ret = $this->selectRecord($queryStr, array($clientId, $widgetId), $row);
+		if ($ret) $retValue = $row['cp_param'];
+		return $retValue;
+	}
+	/**
+	 * クライアント設定値を更新
+	 *
+	 * @param string $clientId		クライアントID
+	 * @param string $widgetId		ウィジェットID
+	 * @param string $value			値
+	 * @return						true = 正常、false=異常
+	 */
+	function updateClientParam($clientId, $widgetId, $value)
+	{
+		$now = date("Y/m/d H:i:s");	// 現在日時
+		$ip = $this->gRequest->trimServerValueOf('REMOTE_ADDR');
+		
+		// データの確認
+		$queryStr  = 'SELECT cp_param FROM _client_param ';
+		$queryStr .=   'WHERE cp_id  = ? ';
+		$queryStr .=     'AND cp_widget_id = ? ';
+		$ret = $this->isRecordExists($queryStr, array($clientId, $widgetId));
+		if ($ret){
+			$queryStr  = 'UPDATE _client_param ';
+			$queryStr .=   'SET cp_param = ?, ';
+			$queryStr .=     'cp_ip = ?, ';
+			$queryStr .=     'cp_update_dt = ? ';
+			$queryStr .=   'WHERE cp_id  = ? ';
+			$queryStr .=     'AND cp_widget_id = ? ';
+			$ret = $this->execStatement($queryStr, array($value, $ip, $now, $clientId, $widgetId));
+			return $ret;
+		} else {
+			$queryStr  = 'INSERT INTO _client_param ';
+			$queryStr .=   '(cp_id, cp_widget_id, cp_param, cp_ip, cp_update_dt) VALUES (?, ?, ?, ?, ?)';
+			$ret = $this->execStatement($queryStr, array($clientId, $widgetId, $value, $ip, $now));
+			return $ret;
+		}
+	}
 }
 ?>
